.. _api_reference:

API Reference
===============

.. toctree::
    :maxdepth: 2

    Synthesizer <synthesizer>
    Data Connector <data_connectors/index>
    Data Models <data_models/index>
    Data Loader <data_loader>
    Cacher for DataLoader <cachers/index>
    Data Processor <data_processors/index>
    Models <models/index>
    Data Exporter <data_exporters/index>
    Manager <manager>
    Exceptions <exceptions>
    Utils <utils>
